@@ -202,10 +202,10 @@ class Server():
             dirnames[:] = [d for d in dirnames if d not in exclude_dirs_set]
             for filename in filenames:
                 if filename in exclude_files_set:
-                    log.warning(f"查找文件: root_dir:{root_dir},suffix:{suffix},with_suffix:{with_suffix},recursive:{recursive},exclude_dirs:{exclude_dirs},exclude_files:{exclude_files},absolute_path:{absolute_path},only_file_name:{only_file_name},文件被排除: {filename}")
+                    log.info(f"查找文件: root_dir:{root_dir},suffix:{suffix},with_suffix:{with_suffix},recursive:{recursive},exclude_dirs:{exclude_dirs},exclude_files:{exclude_files},absolute_path:{absolute_path},only_file_name:{only_file_name},文件被排除: {filename}")
                     continue
                 if suffix is not None and not filename.endswith(suffix):
-                    log.warning(f"查找文件: root_dir:{root_dir},suffix:{suffix},with_suffix:{with_suffix},recursive:{recursive},exclude_dirs:{exclude_dirs},exclude_files:{exclude_files},absolute_path:{absolute_path},only_file_name:{only_file_name},文件后缀不匹配: {filename}")
+                    log.info(f"查找文件: root_dir:{root_dir},suffix:{suffix},with_suffix:{with_suffix},recursive:{recursive},exclude_dirs:{exclude_dirs},exclude_files:{exclude_files},absolute_path:{absolute_path},only_file_name:{only_file_name},文件后缀不匹配: {filename}")
                     continue
                 processed_name = filename if with_suffix else os.path.splitext(filename)[0]
                 if only_file_name:
